[cxf] branch dependabot/maven/io.opentelemetry.semconv-opentelemetry-semconv-1.22.0-alpha created (now 7af05a6722)

2023-10-26 Thread github-bot
This is an automated email from the ASF dual-hosted git repository.

github-bot pushed a change to branch 
dependabot/maven/io.opentelemetry.semconv-opentelemetry-semconv-1.22.0-alpha
in repository https://gitbox.apache.org/repos/asf/cxf.git


  at 7af05a6722 Bump io.opentelemetry.semconv:opentelemetry-semconv

No new revisions were added by this update.



[cxf] 01/02: [JAX-WS] The client out interceptor chain is not called in case of oneway operation (#1472)

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a commit to branch 3.5.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git

commit bb007ff994a557e2c257ad80f8033a068c18772b
Author: Andriy Redko 
AuthorDate: Thu Oct 26 21:27:10 2023 -0400

[JAX-WS] The client out interceptor chain is not called in case of oneway 
operation (#1472)

* [JAX-WS] The client out interceptor chain is not called in case of oneway 
operation

* Remove setting thread local bus

(cherry picked from commit 529f86b93feab01fd15de4593111c75fe58ab52d)

# Conflicts:
#   
integration/tracing/tracing-micrometer/src/main/java/org/apache/cxf/tracing/micrometer/AbstractObservationClientInterceptor.java
(cherry picked from commit cc02e858026cbff95415f56e2a9e690bfb032151)
---
 .../java/org/apache/cxf/endpoint/ClientImpl.java   | 117 -
 .../apache/cxf/interceptor/OneWayInterceptor.java  |  29 +
 .../brave/AbstractBraveClientInterceptor.java  |   3 +-
 .../AbstractOpenTelemetryClientInterceptor.java|   3 +-
 .../AbstractOpenTracingClientInterceptor.java  |   3 +-
 5 files changed, 149 insertions(+), 6 deletions(-)

diff --git a/.gitmergeinfo b/.gitmergeinfo
index 6251342882..2c29213769 100644
--- a/.gitmergeinfo
+++ b/.gitmergeinfo
@@ -221,6 +221,7 @@ B 9313c2a54131b44e8f9c4332671e881bfc35a01e
 B 9329faac7a89979c118dc9b0dcd784245f28ff24
 B 937fb0646cca5d15eda0f9d131309bc9c4871de9
 B 93dd95007be0ac506ae4bf56d1ed25544831c8cb
+B 95927239d5d519621ea2809b164035799b5a5d67
 B 959404f8cc72a91a9ed108bf407c500ed2764688
 B 9652ad4297404686df2d9efc2b5b1cbb0bebd700
 B 9723e32190d3a820e0eecf19177561155399c867
@@ -728,6 +729,7 @@ M df42352ec9642b4e587889aa5644aa5b869d4ae7
 M e216f887e073d9fc6a595b8443682c6a66b27227
 M e272423b0ab885aa886901850360c04d11eb5ba2
 M e2f56083cb79b8b6dc4aa099d795222c8164428a
+M e35f359699a87e41bc9287d761a82a042d342dc3
 M e4bd3c2822a46c42d9751c4cdb6ed5b713a77d6f
 M e5106ca398aee0860d8fe69f0df11692e5c3ad2b
 M e59e123ada4bdf42cfc7eac8fdb3f88607f97a25



[cxf] branch 3.5.x-fixes updated (85dde2e932 -> bb8034d5d1)

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a change to branch 3.5.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git


from 85dde2e932 Recording .gitmergeinfo Changes
 new bb007ff994 [JAX-WS] The client out interceptor chain is not called in 
case of oneway operation (#1472)
 new bb8034d5d1 Recording .gitmergeinfo Changes

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .gitmergeinfo  |   2 +
 .../java/org/apache/cxf/endpoint/ClientImpl.java   | 117 -
 .../apache/cxf/interceptor/OneWayInterceptor.java  |  13 +--
 .../brave/AbstractBraveClientInterceptor.java  |   3 +-
 .../AbstractOpenTelemetryClientInterceptor.java|   3 +-
 .../AbstractOpenTracingClientInterceptor.java  |   3 +-
 6 files changed, 126 insertions(+), 15 deletions(-)
 copy rt/ws/rm/src/main/java/org/apache/cxf/ws/rm/BindingFaultFactory.java => 
core/src/main/java/org/apache/cxf/interceptor/OneWayInterceptor.java (78%)



[cxf] 02/02: Recording .gitmergeinfo Changes

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a commit to branch 3.6.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git

commit 95927239d5d519621ea2809b164035799b5a5d67
Author: Andriy Redko 
AuthorDate: Thu Oct 26 21:35:02 2023 -0400

Recording .gitmergeinfo Changes
---
 .gitmergeinfo | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/.gitmergeinfo b/.gitmergeinfo
index e61ac6ee02..22e6d0bd19 100644
--- a/.gitmergeinfo
+++ b/.gitmergeinfo
@@ -379,6 +379,7 @@ M 4feb1632abee093808fff06e03cf9d951c3ac7c9
 M 5147a509abcee1aa885f0fcace2d797e28347608
 M 5183fbf3c51cac50aa96506a03b6884587cec8ec
 M 52557512cf03c392069befce37977302d5c88539
+M 529f86b93feab01fd15de4593111c75fe58ab52d
 M 5439c3f36b5f8525a0d92831fdf89b4fa2c48d31
 M 546340afed9b6ccf0ca655605ce58287f7d16e5c
 M 54919faf04751a1737b4edf95d8e2e7604bd3226
@@ -409,6 +410,7 @@ M 5c05b6b7defdd87e60419f87d55ded324e9a7738
 M 5c37d05ec7a26a9e72c5169b1f427087cf123993
 M 5c64b7a10227d59cd61f9e61a64496e57bf2e1b6
 M 5d653425990f06f3706dace88cf65b64ca2641e2
+M 5dd6e8f78beffe9a743fce52549fa1c230782962
 M 5e1c602fc784985b2b1bf8e40a0564dd8f09db08
 M 5e88225f5b45ca03416e616e77f602e62b25ace5
 M 5f9d2e08452cd79a85f06b5ff0e830d084deaf1b
@@ -433,6 +435,7 @@ M 66368976c7260eefd734dd0416b00f077176459e
 M 66538c79f2d7ec8366905d2565b3cf5ff1b5ed84
 M 66f581222723f7fb3aaf8b7c0f50a117db6b0ea6
 M 671cf75bcf3eb169eb98cbe398131ad9f9551529
+M 67f9be7d08a28027c21375c736a5030989eca039
 M 683e2b1bbd5f629d2d6d5726849f6f8d16298202
 M 688e0c16e8a760c839c52f01e210998c947c0037
 M 6a20f8231c9adf2e898c2c1d1ee84f74a529f737



[cxf] branch 3.6.x-fixes updated (45188882b1 -> 95927239d5)

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a change to branch 3.6.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git


from 4512b1 Recording .gitmergeinfo Changes
 new cc02e85802 [JAX-WS] The client out interceptor chain is not called in 
case of oneway operation (#1472)
 new 95927239d5 Recording .gitmergeinfo Changes

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .gitmergeinfo  |   3 +
 .../java/org/apache/cxf/endpoint/ClientImpl.java   | 117 -
 .../apache/cxf/interceptor/OneWayInterceptor.java  |  13 +--
 .../brave/AbstractBraveClientInterceptor.java  |   3 +-
 .../AbstractOpenTelemetryClientInterceptor.java|   3 +-
 .../AbstractOpenTracingClientInterceptor.java  |   3 +-
 6 files changed, 127 insertions(+), 15 deletions(-)
 copy rt/ws/rm/src/main/java/org/apache/cxf/ws/rm/BindingFaultFactory.java => 
core/src/main/java/org/apache/cxf/interceptor/OneWayInterceptor.java (78%)



[cxf] 01/02: [JAX-WS] The client out interceptor chain is not called in case of oneway operation (#1472)

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a commit to branch 3.6.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git

commit cc02e858026cbff95415f56e2a9e690bfb032151
Author: Andriy Redko 
AuthorDate: Thu Oct 26 21:27:10 2023 -0400

[JAX-WS] The client out interceptor chain is not called in case of oneway 
operation (#1472)

* [JAX-WS] The client out interceptor chain is not called in case of oneway 
operation

* Remove setting thread local bus

(cherry picked from commit 529f86b93feab01fd15de4593111c75fe58ab52d)

# Conflicts:
#   
integration/tracing/tracing-micrometer/src/main/java/org/apache/cxf/tracing/micrometer/AbstractObservationClientInterceptor.java
---
 .../java/org/apache/cxf/endpoint/ClientImpl.java   | 117 -
 .../apache/cxf/interceptor/OneWayInterceptor.java  |  29 +
 .../brave/AbstractBraveClientInterceptor.java  |   3 +-
 .../AbstractOpenTelemetryClientInterceptor.java|   3 +-
 .../AbstractOpenTracingClientInterceptor.java  |   3 +-
 5 files changed, 149 insertions(+), 6 deletions(-)

diff --git a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java 
b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
index 53d3a432b8..2bee3982ae 100644
--- a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
+++ b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
@@ -36,6 +36,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.stream.Collectors;
 
 import javax.xml.namespace.QName;
 import javax.xml.ws.handler.MessageContext;
@@ -55,6 +56,7 @@ import org.apache.cxf.interceptor.Fault;
 import org.apache.cxf.interceptor.Interceptor;
 import org.apache.cxf.interceptor.InterceptorChain;
 import org.apache.cxf.interceptor.InterceptorProvider;
+import org.apache.cxf.interceptor.OneWayInterceptor;
 import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.ExchangeImpl;
 import org.apache.cxf.message.Message;
@@ -622,9 +624,14 @@ public class ClientImpl
 }
 }
 
-// Wait for a response if we need to
-if (oi != null && !oi.getOperationInfo().isOneWay()) {
-waitResponse(exchange);
+if (oi != null) { 
+if (!oi.getOperationInfo().isOneWay()) {
+// Wait for a response if we need to
+waitResponse(exchange);
+} else {
+// Trigger the interceptors chain
+onewayOnly(exchange);
+}
 }
 
 // leave the input stream open for the caller
@@ -672,6 +679,92 @@ public class ClientImpl
 
 return null;
 }
+
+protected void onewayOnly(Exchange exhange) {
+if (bus == null) {
+throw new IllegalStateException("Message received on a Client that 
has been closed or destroyed.");
+}
+
+Message original = exhange.getInMessage();
+if (original == null) {
+// This is one way call and we may not even have incoming message
+original = exhange.getOutMessage();
+}
+
+if (original == null) {
+original = new MessageImpl();
+}
+
+Endpoint endpoint = exhange.getEndpoint();
+if (endpoint == null) {
+// in this case correlation will occur outside the transport,
+// however there's a possibility that the endpoint may have been
+// rebased in the meantime, so that the response will be mediated
+// via a set of in interceptors provided by a *different* endpoint
+//
+endpoint = getConduitSelector().getEndpoint();
+original.getExchange().put(Endpoint.class, endpoint);
+}
+
+final Message message = endpoint.getBinding().createMessage(original);
+message.getExchange().setInMessage(message);
+message.put(Message.REQUESTOR_ROLE, Boolean.TRUE);
+message.put(Message.INBOUND_MESSAGE, Boolean.TRUE);
+PhaseManager pm = bus.getExtension(PhaseManager.class);
+
+List> i1 = 
filterOneway(bus.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by bus: " + i1);
+}
+List> i2 = 
filterOneway(getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by client: " + i2);
+}
+List> i3 = 
filterOneway(endpoint.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by endpoint: " + i3);
+}
+List> i4 = 
filterOneway(endpoint.getBinding().getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway intercept

[cxf] 02/02: Recording .gitmergeinfo Changes

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a commit to branch 3.5.x-fixes
in repository https://gitbox.apache.org/repos/asf/cxf.git

commit bb8034d5d14d2c2f5e8aaa8ef6a78548290f6825
Author: Andriy Redko 
AuthorDate: Thu Oct 26 21:44:11 2023 -0400

Recording .gitmergeinfo Changes
---
 .gitmergeinfo | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java 
b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
index 53d3a432b8..2bee3982ae 100644
--- a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
+++ b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
@@ -36,6 +36,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.stream.Collectors;
 
 import javax.xml.namespace.QName;
 import javax.xml.ws.handler.MessageContext;
@@ -55,6 +56,7 @@ import org.apache.cxf.interceptor.Fault;
 import org.apache.cxf.interceptor.Interceptor;
 import org.apache.cxf.interceptor.InterceptorChain;
 import org.apache.cxf.interceptor.InterceptorProvider;
+import org.apache.cxf.interceptor.OneWayInterceptor;
 import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.ExchangeImpl;
 import org.apache.cxf.message.Message;
@@ -622,9 +624,14 @@ public class ClientImpl
 }
 }
 
-// Wait for a response if we need to
-if (oi != null && !oi.getOperationInfo().isOneWay()) {
-waitResponse(exchange);
+if (oi != null) { 
+if (!oi.getOperationInfo().isOneWay()) {
+// Wait for a response if we need to
+waitResponse(exchange);
+} else {
+// Trigger the interceptors chain
+onewayOnly(exchange);
+}
 }
 
 // leave the input stream open for the caller
@@ -672,6 +679,92 @@ public class ClientImpl
 
 return null;
 }
+
+protected void onewayOnly(Exchange exhange) {
+if (bus == null) {
+throw new IllegalStateException("Message received on a Client that 
has been closed or destroyed.");
+}
+
+Message original = exhange.getInMessage();
+if (original == null) {
+// This is one way call and we may not even have incoming message
+original = exhange.getOutMessage();
+}
+
+if (original == null) {
+original = new MessageImpl();
+}
+
+Endpoint endpoint = exhange.getEndpoint();
+if (endpoint == null) {
+// in this case correlation will occur outside the transport,
+// however there's a possibility that the endpoint may have been
+// rebased in the meantime, so that the response will be mediated
+// via a set of in interceptors provided by a *different* endpoint
+//
+endpoint = getConduitSelector().getEndpoint();
+original.getExchange().put(Endpoint.class, endpoint);
+}
+
+final Message message = endpoint.getBinding().createMessage(original);
+message.getExchange().setInMessage(message);
+message.put(Message.REQUESTOR_ROLE, Boolean.TRUE);
+message.put(Message.INBOUND_MESSAGE, Boolean.TRUE);
+PhaseManager pm = bus.getExtension(PhaseManager.class);
+
+List> i1 = 
filterOneway(bus.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by bus: " + i1);
+}
+List> i2 = 
filterOneway(getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by client: " + i2);
+}
+List> i3 = 
filterOneway(endpoint.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by endpoint: " + i3);
+}
+List> i4 = 
filterOneway(endpoint.getBinding().getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by binding: " + i4);
+}
+
+PhaseIntercept

[cxf] branch main updated: [JAX-WS] The client out interceptor chain is not called in case of oneway operation (#1472)

2023-10-26 Thread reta
This is an automated email from the ASF dual-hosted git repository.

reta pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/cxf.git


The following commit(s) were added to refs/heads/main by this push:
 new 529f86b93f [JAX-WS] The client out interceptor chain is not called in 
case of oneway operation (#1472)
529f86b93f is described below

commit 529f86b93feab01fd15de4593111c75fe58ab52d
Author: Andriy Redko 
AuthorDate: Thu Oct 26 21:27:10 2023 -0400

[JAX-WS] The client out interceptor chain is not called in case of oneway 
operation (#1472)

* [JAX-WS] The client out interceptor chain is not called in case of oneway 
operation

* Remove setting thread local bus
---
 .../java/org/apache/cxf/endpoint/ClientImpl.java   | 117 -
 .../apache/cxf/interceptor/OneWayInterceptor.java  |  29 +
 .../brave/AbstractBraveClientInterceptor.java  |   3 +-
 .../AbstractObservationClientInterceptor.java  |   3 +-
 .../AbstractOpenTelemetryClientInterceptor.java|   3 +-
 .../AbstractOpenTracingClientInterceptor.java  |   3 +-
 6 files changed, 151 insertions(+), 7 deletions(-)

diff --git a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java 
b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
index 43f8bf4e84..420263953e 100644
--- a/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
+++ b/core/src/main/java/org/apache/cxf/endpoint/ClientImpl.java
@@ -36,6 +36,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import java.util.stream.Collectors;
 
 import javax.xml.namespace.QName;
 
@@ -55,6 +56,7 @@ import org.apache.cxf.interceptor.Fault;
 import org.apache.cxf.interceptor.Interceptor;
 import org.apache.cxf.interceptor.InterceptorChain;
 import org.apache.cxf.interceptor.InterceptorProvider;
+import org.apache.cxf.interceptor.OneWayInterceptor;
 import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.ExchangeImpl;
 import org.apache.cxf.message.Message;
@@ -622,9 +624,14 @@ public class ClientImpl
 }
 }
 
-// Wait for a response if we need to
-if (oi != null && !oi.getOperationInfo().isOneWay()) {
-waitResponse(exchange);
+if (oi != null) { 
+if (!oi.getOperationInfo().isOneWay()) {
+// Wait for a response if we need to
+waitResponse(exchange);
+} else {
+// Trigger the interceptors chain
+onewayOnly(exchange);
+}
 }
 
 // leave the input stream open for the caller
@@ -672,6 +679,92 @@ public class ClientImpl
 
 return null;
 }
+
+protected void onewayOnly(Exchange exhange) {
+if (bus == null) {
+throw new IllegalStateException("Message received on a Client that 
has been closed or destroyed.");
+}
+
+Message original = exhange.getInMessage();
+if (original == null) {
+// This is one way call and we may not even have incoming message
+original = exhange.getOutMessage();
+}
+
+if (original == null) {
+original = new MessageImpl();
+}
+
+Endpoint endpoint = exhange.getEndpoint();
+if (endpoint == null) {
+// in this case correlation will occur outside the transport,
+// however there's a possibility that the endpoint may have been
+// rebased in the meantime, so that the response will be mediated
+// via a set of in interceptors provided by a *different* endpoint
+//
+endpoint = getConduitSelector().getEndpoint();
+original.getExchange().put(Endpoint.class, endpoint);
+}
+
+final Message message = endpoint.getBinding().createMessage(original);
+message.getExchange().setInMessage(message);
+message.put(Message.REQUESTOR_ROLE, Boolean.TRUE);
+message.put(Message.INBOUND_MESSAGE, Boolean.TRUE);
+PhaseManager pm = bus.getExtension(PhaseManager.class);
+
+List> i1 = 
filterOneway(bus.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by bus: " + i1);
+}
+List> i2 = 
filterOneway(getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by client: " + i2);
+}
+List> i3 = 
filterOneway(endpoint.getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by endpoint: " + i3);
+}
+List> i4 = 
filterOneway(endpoint.getBinding().getInInterceptors());
+if (LOG.isLoggable(Level.FINE)) {
+LOG.fine("Oneway interceptors contributed by binding: " + i4);
+}
+
+PhaseInterceptorChain chain;
+